refresh_token = {
  "refreshToken": "REFRESH_TOKEN"
}

test_run_v1 = {
  "name": "Test NG run",
  "startedAt": "2019-12-03T10:15:30+01:00",
  "framework": "testng"
}


test_v1 = {
  "uuid": "1512351235-3215-3125-3215531",
  "name": "Test ABC",
  "className": "com.test.MyTests",
  "methodName": "featureTest()",
  "startedAt": "2007-12-03T10:15:30Z"

}


test_result_v1 = {
  "result": "failed",
  "endedAt": "2007-12-03T10:15:30Z"
}


test_log = []